@@ -58,6 +58,7 @@ import com.openexchange.mobile.api.facade.auth.impl.LogoutConnector;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactory;
 import com.openexchange.mobile.api.facade.connectors.RequestConfiguration;
 import com.openexchange.mobile.api.facade.models.Folder;
+import com.openexchange.mobile.api.facade.models.MailAccountData;
 import com.openexchange.mobile.api.facade.models.MailFlags;
 import com.openexchange.mobile.api.facade.utils.RequestUtil;
 
@@ -69,6 +70,11 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         configuration = RequestUtil.createConfiguration();
     }
 
+    @Override
+    public GetAccountConnector getAccountConnector(SessionData sessionData, String accountId) {
+        return new GetAccountConnector(configuration, sessionData, accountId);
+    }
+
     @Override
     public AccountsConnector getAccountsConnector(SessionData sessionData) {
         return new AccountsConnector(configuration, sessionData);
@@ -99,6 +105,11 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         return new ContactsConnector(configuration, sessionData);
     }
 
+    @Override
+    public DeleteAccountConnector getDeleteAccountConnector(SessionData sessionData, String accountId) {
+        return new DeleteAccountConnector(configuration, sessionData, accountId);
+    }
+
     @Override
     public CreateFolderConnector getCreateFolderConnector(SessionData sessionData, String parentFolderId, String name) {
         return new CreateFolderConnector(configuration, sessionData, parentFolderId, name);
@@ -144,6 +155,11 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         return new LogoutConnector(configuration, sessionData);
     }
 
+    @Override
+    public CreateAccountConnector getCreateAccountConnector(SessionData sessionData, MailAccountData account) {
+        return new CreateAccountConnector(configuration, sessionData, account);
+    }
+
     @Override
     public ManifestsConnector getManifestsConnector() {
         return new ManifestsConnector(configuration);
@@ -189,11 +205,21 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         return new ThreadReferencesConnector(configuration, sessionData, folderId);
     }
 
+    @Override
+    public UpdateAccountConnector getUpdateAccountConnector(SessionData sessionData, MailAccountData account) {
+        return new UpdateAccountConnector(configuration, sessionData, account);
+    }
+
     @Override
     public UserConnector getUserConnector(SessionData sessionData) {
         return new UserConnector(configuration, sessionData);
     }
 
+    @Override
+    public ValidateAccountConnector getValidateAccountConnector(SessionData sessionData, MailAccountData account, boolean forceInsecureConnection) {
+        return new ValidateAccountConnector(configuration, sessionData, account, forceInsecureConnection);
+    }
+
     @Override
     public VersionConnector getVersionConnector() {
         return new VersionConnector(configuration);
